# -*- coding: utf-8 -*-
from django.core.exceptions import PermissionDenied
from django.http import FileResponse
from django.views.generic.detail import DetailView

from .models import Attachment


class AttachmentDownloadView(DetailView):
    model = Attachment

    def check_permissions(self, request):
        user = request.user
        app_label = self.model._meta.app_label
        model_name = self.model._meta.model_name
        if not user.has_perms(('miscellaneous.download_attachment', f'{app_label}.download_{model_name}')):
            raise PermissionDenied()
        return

    def get(self, request, *args, **kwargs):
        super().get(request, *args, **kwargs)
        self.check_permissions(request)
        return FileResponse(
            open(self.object.attachment.path, 'rb'),
            as_attachment=True,
            filename=f'{self.object.attachment}'
        )
