# -*- coding: utf-8 -*-

import urllib

import requests
from django.urls import reverse


class RemoteTestMixin:
    # COMMENT - superuser
    def v1_superuser_miscellaneous_comment_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-miscellaneous:comment-list',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_superuser_miscellaneous_comment_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-miscellaneous:comment-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_superuser_miscellaneous_comment_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-miscellaneous:comment-list',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_miscellaneous_comment_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-miscellaneous:comment-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_miscellaneous_comment_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-miscellaneous:comment-enable',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_miscellaneous_comment_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-miscellaneous:comment-disable',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_miscellaneous_comment_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-miscellaneous:comment-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_superuser_miscellaneous_comment_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-miscellaneous:comment-light',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_superuser_miscellaneous_comment_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-miscellaneous:comment-status-choices',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # COMMENT - administrator

    def v1_administrator_miscellaneous_comment_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-miscellaneous:comment-list',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_administrator_miscellaneous_comment_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-miscellaneous:comment-detail',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_administrator_miscellaneous_comment_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-miscellaneous:comment-list',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_miscellaneous_comment_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-miscellaneous:comment-detail',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_miscellaneous_comment_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-miscellaneous:comment-enable',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_miscellaneous_comment_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-miscellaneous:comment-disable',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_miscellaneous_comment_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-miscellaneous:comment-detail',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_administrator_miscellaneous_comment_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-miscellaneous:comment-light',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_administrator_miscellaneous_comment_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-miscellaneous:comment-status-choices',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # COMMENT - manager

    def v1_manager_miscellaneous_comment_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-miscellaneous:comment-list',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_manager_miscellaneous_comment_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-miscellaneous:comment-detail',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_manager_miscellaneous_comment_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-miscellaneous:comment-list',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_miscellaneous_comment_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-miscellaneous:comment-detail',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_miscellaneous_comment_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-miscellaneous:comment-enable',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_miscellaneous_comment_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-miscellaneous:comment-disable',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_miscellaneous_comment_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-miscellaneous:comment-detail',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_manager_miscellaneous_comment_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-miscellaneous:comment-light',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_manager_miscellaneous_comment_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-miscellaneous:comment-status-choices',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # COMMENT - assistant

    def v1_assistant_miscellaneous_comment_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-miscellaneous:comment-list',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_assistant_miscellaneous_comment_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-miscellaneous:comment-detail',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_assistant_miscellaneous_comment_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-miscellaneous:comment-list',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_miscellaneous_comment_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-miscellaneous:comment-detail',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_miscellaneous_comment_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-miscellaneous:comment-enable',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_miscellaneous_comment_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-miscellaneous:comment-disable',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_miscellaneous_comment_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-miscellaneous:comment-detail',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_assistant_miscellaneous_comment_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-miscellaneous:comment-light',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_assistant_miscellaneous_comment_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-miscellaneous:comment-status-choices',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # ATTACHMENT - superuser

    def v1_superuser_miscellaneous_attachment_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-miscellaneous:attachment-list',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_superuser_miscellaneous_attachment_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-miscellaneous:attachment-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_superuser_miscellaneous_attachment_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-miscellaneous:attachment-list',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_miscellaneous_attachment_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-miscellaneous:attachment-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_miscellaneous_attachment_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-miscellaneous:attachment-enable',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_miscellaneous_attachment_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-miscellaneous:attachment-disable',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_superuser_miscellaneous_attachment_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-miscellaneous:attachment-detail',
            args=('superuser', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_superuser_miscellaneous_attachment_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-miscellaneous:attachment-light',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_superuser_miscellaneous_attachment_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-miscellaneous:attachment-status-choices',
            args=('superuser',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # ATTACHMENT - administrator

    def v1_administrator_miscellaneous_attachment_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-miscellaneous:attachment-list',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_administrator_miscellaneous_attachment_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-miscellaneous:attachment-detail',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_administrator_miscellaneous_attachment_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-miscellaneous:attachment-list',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_miscellaneous_attachment_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-miscellaneous:attachment-detail',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_miscellaneous_attachment_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-miscellaneous:attachment-enable',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_miscellaneous_attachment_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-miscellaneous:attachment-disable',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_administrator_miscellaneous_attachment_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-miscellaneous:attachment-detail',
            args=('administrator', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_administrator_miscellaneous_attachment_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-miscellaneous:attachment-light',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_administrator_miscellaneous_attachment_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-miscellaneous:attachment-status-choices',
            args=('administrator',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # ATTACHMENT - manager

    def v1_manager_miscellaneous_attachment_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-miscellaneous:attachment-list',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_manager_miscellaneous_attachment_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-miscellaneous:attachment-detail',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_manager_miscellaneous_attachment_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-miscellaneous:attachment-list',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_miscellaneous_attachment_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-miscellaneous:attachment-detail',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_miscellaneous_attachment_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-miscellaneous:attachment-enable',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_miscellaneous_attachment_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-miscellaneous:attachment-disable',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_manager_miscellaneous_attachment_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-miscellaneous:attachment-detail',
            args=('manager', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_manager_miscellaneous_attachment_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-miscellaneous:attachment-light',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_manager_miscellaneous_attachment_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-miscellaneous:attachment-status-choices',
            args=('manager',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    # ATTACHMENT - assistant

    def v1_assistant_miscellaneous_attachment_list(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-miscellaneous:attachment-list',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_assistant_miscellaneous_attachment_retrieve(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-miscellaneous:attachment-detail',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_assistant_miscellaneous_attachment_create(self, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-miscellaneous:attachment-list',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.post(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_miscellaneous_attachment_update(self, pk, post_dict):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-miscellaneous:attachment-detail',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_miscellaneous_attachment_enable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-miscellaneous:attachment-enable',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_miscellaneous_attachment_disable(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-miscellaneous:attachment-disable',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        post_dict = {}
        resp = requests.patch(url, headers=self.get_headers(), json=post_dict)
        self.rprint(resp)
        return resp

    def v1_assistant_miscellaneous_attachment_destroy(self, pk):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-miscellaneous:attachment-detail',
            args=('assistant', pk,)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.delete(url, headers=self.get_headers())
        self.rprint(resp)
        return resp

    def v1_assistant_miscellaneous_attachment_light(self, filters=None):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-miscellaneous:attachment-light',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers(), params=filters)
        self.rprint(resp)
        return resp

    def v1_assistant_miscellaneous_attachment_status_choices(self):
        self.token_refresh()
        endpoint = reverse(
            'api-v1-miscellaneous:attachment-status-choices',
            args=('assistant',)
        )
        url = urllib.parse.urljoin(self.base_url, endpoint)
        resp = requests.get(url, headers=self.get_headers())
        self.rprint(resp)
        return resp
